yt.utilities.initial\_conditions module
=======================================

.. automodule:: yt.utilities.initial_conditions
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
